@@ -6,13 +6,14 @@ use strict;
 # use warnings; # 5.006 feature
 
 use vars qw($VERSION);
-$VERSION = '0.11';
+$VERSION = '0.12';
 
-# $VERSION = eval $VERSION;
+$VERSION = eval $VERSION;
 
 use Log::Dispatch 2.01;
 use base qw(Log::Dispatch::Output);
 
+use Win32 ();
 use Win32::EventLog;
 
 use Params::Validate qw(validate SCALAR);
@@ -34,10 +35,20 @@ sub new {
     $self->{win32_log}    = "Application";
 
     if ($self->{win32_source} =~ /[\\]/) {
-      die "Invalid characters in source";
+      $self->{win32_source} =~ s/\\/_/g; # 
+      warn "Backslashes in source removed";
     }
 
     if ($params{register}) {
+
+      # We want to use Win32::IsAdminUser to check if a user is an
+      # administrator, but this only appears to be available in Win32
+      # v0.23, with Perl 5.8.4.
+
+#       unless (Win32::IsAdminUser) {
+# 	  warn "Admin user is required to register event sources";
+#       }
+
       eval {
 	require Win32::EventLog::Message;
 	import Win32::EventLog::Message;
@@ -159,13 +170,15 @@ Same as various Log::Dispatch::* classes.
 This will be the source that the event is recorded from.  Usually this
 is the name of your application.
 
-The source should not contain any backslash characters.
+The source name should I<not> contain any backslash characters.  If it
+does, they will be changed to underscores and a warning will be
+issued.  This is due to a restriction of the NT Event Log.
 
 =item register
 
-This specifies which event log to register the source with, if you
-want to register your source, or to post to a log other than the
-Application log.
+Registration of an event source removes the warning about the event
+being from an unknown source.  It also allows you to post to a log
+other than the Application log.
 
 When you register a source to particular log, all future events will
 be posted to that log, even if you unregister the source and attempt
@@ -179,15 +192,34 @@ will be tagged as "Audit Success" and higher levels will be tagged as
 In order to use this feature, you must have
 L<Win32::EventLog::Message> installed.
 
+The process that registers the event sources may need permission to
+register the event.  In some cases you may first need to run a simple
+script which registers the source name while logged in as an
+administrator:
+
+  use Log::Dispatch;
+  use Log::Dispatch::Win32EventLog 0.10;
+
+  my $dispatch = Log::Dispatch->new;
+  
+  $dispatch->add( Log::Dispatch::Win32EventLog->new(
+    source   => 'MySourceName',
+    register => 'System',
+  );
+
+afterwards the source name should be properly registered, and any
+script with rights to post to the event logs should be able to post.
+
+I<This is an experimental feature that may not work properly on all
+systems.>
+
 =item log_message
 
-inherited from Log::Dispatch::Output.
+inherited from L<Log::Dispatch::Output>.
 
 =back
 
-=head1 OTHER TOPICS
-
-=head1 Using with Log4perl
+=head2 Using with Log4perl
 
 This module can be used as a L<Log::Log4perl> appender.  The
 configuration file should have the following:
@@ -199,6 +231,37 @@ configuration file should have the following:
 
 Replace MySourceName with the source name of your application.
 
+You can also use the log4j wrapper instead:
+
+  log4j.category.cat1                = INFO, myAppender
+
+  log4j.appender.myAppender          = org.apache.log4j.NTEventLogAppender
+  log4j.appender.myAppender.source   = MySourceName
+  log4j.appender.myAppender.layout   = org.apache.log4j.SimpleLayout
+
+See L<Log::Log4perl::JavaMap::NTEventLogAppender> for more information.
+
+=head1 KNOWN ISSUES
+
+See L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Log-Dispatch-Win32EventLog>
+for an up-to-date list of known issues and bugs.
+
+=head2 IIS and Windows Server 2003
+
+In some server configurations using IIS (Windows Server 2003), you may
+need to set security policy to grant permissions to write to the event
+log(s).
+
+See Microsoft KnowledgeBase Article 323076 at
+L<http://support.microsoft.com/default.aspx?scid=kb;en-us;323076>.
+
+=head2 Older versions of Win32.pm
+
+Earlier versions of L<Win32> do not have a function called C<IsAdminUser>.
+Tests which require the user to be an administrator will be skipped, with
+a message saying that the "User is not an administrator" (even when the
+user is an administrator).
+
 =head1 SEE ALSO
 
 L<Log::Dispatch>, L<Win32::EventLog>, L<Log::Log4perl>
@@ -216,6 +279,11 @@ Arthur Bergman E<lt>abergman at cpan.orgE<gt>
 
 Gunnar Hansson E<lt>gunnar at telefonplan.nuE<gt>
 
+=head2 Acknowledgements
+
+Much thanks to Frank Chan E<lt>fpchan at aol.comE<gt> for testing
+several developer releases of this module.
+
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
